@@ -19,10 +19,11 @@ def plot(graph, particles=None, polyline=None, label_start_end=True,
          **kwargs):
     """
     Plots particle approximation of trajectory
+
     :param graph: NetworkX MultiDiGraph
         UTM projection
         encodes road network
-        generating using OSMnx, see tools.cam_graph.py
+        e.g. generated using OSMnx
     :param particles: MMParticles object (from inference.particles)
         particle approximation
     :param polyline: list-like, each element length 2
